@@ -1,16 +1,5 @@
-import spacy
 from sys import stderr
 
-try:
-    nlp = spacy.load('en')
-except OSError:
-    print('Downloading language model for the spaCy POS tagger\n'
-          "(don't worry, this will only happen once)", file=stderr)
-    from spacy.cli import download
-    download('en')
-    nlp = spacy.load('en')
-
-
 def isParenthetical(text):
     return "(" in text[0] and ")" in text[-1]
 
@@ -52,10 +41,5 @@ def isCharacter(currentContent):
     if any(x in text[-1] for x in ["-", "."]):
         return False
 
-    if ")" not in text:
-        check = nlp(text)
-        for word in check:
-            if "VERB" == word.pos_ or "ADP" == word.pos_ or "DET" == word.pos_:
-                return False
 
     return True
